@@ -3,11 +3,10 @@
 #[macro_use]
 extern crate pmutil;
 extern crate proc_macro;
-extern crate proc_macro2;
 #[macro_use]
 extern crate quote;
-extern crate swc_macros_common;
-extern crate syn;
+
+use syn;
 
 use pmutil::prelude::Quote;
 use swc_macros_common::prelude::*;
@@ -106,7 +105,6 @@ fn derive_fmt(i: &DeriveInput, trait_path: TokenStream) -> ItemImpl {
         ))
         .parse::<ItemImpl>()
         .with_generics(i.generics.clone())
-        .into()
 }
 
 fn get_str_value(attrs: &[Attribute]) -> String {
@@ -114,7 +112,7 @@ fn get_str_value(attrs: &[Attribute]) -> String {
     let docs: Vec<_> = attrs.iter().map(doc_str).filter_map(|o| o).collect();
     for raw_line in docs {
         let line = raw_line.trim();
-        if line.starts_with("`") && line.ends_with("`") {
+        if line.starts_with('`') && line.ends_with('`') {
             let mut s: String = line.split_at(1).1.into();
             let new_len = s.len() - 1;
             s.truncate(new_len);
@@ -156,11 +154,10 @@ fn make_from_str(i: &DeriveInput) -> ItemImpl {
                     .filter(|attr| is_attr_name(attr, "cfg"))
                     .cloned()
                     .collect(),
-                pats: vec![Element::End(pat)].into_iter().collect(),
+                pat,
                 guard: None,
                 fat_arrow_token: def_site(),
                 comma: Some(def_site()),
-                leading_vert: None,
             }
         })
         .chain(::std::iter::once({
@@ -201,7 +198,6 @@ fn make_from_str(i: &DeriveInput) -> ItemImpl {
         ))
         .parse::<ItemImpl>()
         .with_generics(i.generics.clone())
-        .into()
 }
 
 fn make_as_str(i: &DeriveInput) -> ItemImpl {
@@ -224,6 +220,7 @@ fn make_as_str(i: &DeriveInput) -> ItemImpl {
                 Fields::Unit => Box::new(Pat::Path(PatPath {
                     qself: None,
                     path: qual_name,
+                    attrs: Default::default(),
                 })),
                 _ => Box::new(
                     Quote::new(def_site::<Span>())
@@ -240,17 +237,15 @@ fn make_as_str(i: &DeriveInput) -> ItemImpl {
                     .filter(|attr| is_attr_name(attr, "cfg"))
                     .cloned()
                     .collect(),
-                pats: vec![Element::End(Pat::Ref(PatRef {
+                pat: Pat::Reference(PatReference {
                     and_token: def_site(),
                     mutability: None,
                     pat,
-                }))]
-                .into_iter()
-                .collect(),
+                    attrs: Default::default(),
+                }),
                 guard: None,
                 fat_arrow_token: def_site(),
                 comma: Some(def_site()),
-                leading_vert: None,
             }
         })
         .collect();
@@ -284,7 +279,6 @@ fn make_as_str(i: &DeriveInput) -> ItemImpl {
         ))
         .parse::<ItemImpl>()
         .with_generics(i.generics.clone())
-        .into()
 }
 
 fn make_as_str_ident() -> Ident {
@@ -305,7 +299,6 @@ fn make_serialize(i: &DeriveInput) -> ItemImpl {
         }))
         .parse::<ItemImpl>()
         .with_generics(i.generics.clone())
-        .into()
 }
 
 fn make_deserialize(i: &DeriveInput) -> ItemImpl {
@@ -341,5 +334,4 @@ fn make_deserialize(i: &DeriveInput) -> ItemImpl {
         }))
         .parse::<ItemImpl>()
         .with_generics(i.generics.clone())
-        .into()
 }
